@@ -16,12 +16,12 @@
 #include "kget_debug.h"
 #include <QDebug>
 
-Job::Job(Scheduler * scheduler, JobQueue * parent)
-    : QObject(parent),
-      m_jobQueue(parent),
-      m_scheduler(scheduler),
-      m_status(Stopped),
-      m_policy(None)
+Job::Job(Scheduler *scheduler, JobQueue *parent)
+    : QObject(parent)
+    , m_jobQueue(parent)
+    , m_scheduler(scheduler)
+    , m_status(Stopped)
+    , m_policy(None)
 {
     m_error.id = -1;
     m_error.type = AutomaticRetry;
@@ -33,12 +33,12 @@ Job::~Job()
 
 void Job::setStatus(Status jobStatus)
 {
-    if(jobStatus == m_status)
+    if (jobStatus == m_status)
         return;
     if (m_status == Aborted) {
         m_error.id = -1;
         m_error.text.clear();
-        m_error.pixmap = QPixmap();
+        m_error.iconName = QString();
         m_error.type = AutomaticRetry;
     }
     m_status = jobStatus;
@@ -53,7 +53,7 @@ void Job::setStartStatus(Status jobStatus)
 
 void Job::setPolicy(Policy jobPolicy)
 {
-    if(jobPolicy == m_policy)
+    if (jobPolicy == m_policy)
         return;
 
     qCDebug(KGET_DEBUG) << "Job::setPolicy(" << jobPolicy << ")";
@@ -62,12 +62,12 @@ void Job::setPolicy(Policy jobPolicy)
     m_scheduler->jobChangedEvent(this, m_policy);
 }
 
-void Job::setError(const QString &text, const QPixmap &pixmap, ErrorType type, int errorId)
+void Job::setError(const QString &text, const QString &iconName, ErrorType type, int errorId)
 {
     setStatus(Job::Aborted);
     m_error.id = errorId;
     m_error.text = text;
-    m_error.pixmap = pixmap;
+    m_error.iconName = iconName;
     m_error.type = type;
 }
 
